@@ -10,6 +10,8 @@
 @see: http://www.mathworks.com/matlabcentral/fileexchange/loadFile.do?objectId=12734&objectType=FILE
 
 """
+
+from matplotlib import pyplot as plt
 import numpy
 import scipy
 import scipy.optimize
@@ -19,7 +21,6 @@ from EMpy.modesolvers.interface import Mode, ModeSolver
 
 
 class SVFDModeSolver(ModeSolver):
-
     """
     This function calculates the modes of a dielectric waveguide
     using the semivectorial finite difference method.
@@ -142,10 +143,8 @@ class SVFDModeSolver(ModeSolver):
                 * (p * (ep - ew) + 2 * w * ew)
                 * ee
                 / (
-                    (p * (ep - ee) + 2 * e * ee)
-                    * (p**2 * (ep - ew) + 4 * w**2 * ew)
-                    + (p * (ep - ew) + 2 * w * ew)
-                    * (p**2 * (ep - ee) + 4 * e**2 * ee)
+                    (p * (ep - ee) + 2 * e * ee) * (p**2 * (ep - ew) + 4 * w**2 * ew)
+                    + (p * (ep - ew) + 2 * w * ew) * (p**2 * (ep - ee) + 4 * e**2 * ee)
                 )
             )
             Aw = (
@@ -153,10 +152,8 @@ class SVFDModeSolver(ModeSolver):
                 * (p * (ep - ee) + 2 * e * ee)
                 * ew
                 / (
-                    (p * (ep - ee) + 2 * e * ee)
-                    * (p**2 * (ep - ew) + 4 * w**2 * ew)
-                    + (p * (ep - ew) + 2 * w * ew)
-                    * (p**2 * (ep - ee) + 4 * e**2 * ee)
+                    (p * (ep - ee) + 2 * e * ee) * (p**2 * (ep - ew) + 4 * w**2 * ew)
+                    + (p * (ep - ew) + 2 * w * ew) * (p**2 * (ep - ee) + 4 * e**2 * ee)
                 )
             )
             Ap = ep * k**2 - An - As - Ae * ep / ee - Aw * ep / ew
@@ -169,10 +166,8 @@ class SVFDModeSolver(ModeSolver):
                 * (q * (ep - es) + 2 * s * es)
                 * en
                 / (
-                    (q * (ep - en) + 2 * n * en)
-                    * (q**2 * (ep - es) + 4 * s**2 * es)
-                    + (q * (ep - es) + 2 * s * es)
-                    * (q**2 * (ep - en) + 4 * n**2 * en)
+                    (q * (ep - en) + 2 * n * en) * (q**2 * (ep - es) + 4 * s**2 * es)
+                    + (q * (ep - es) + 2 * s * es) * (q**2 * (ep - en) + 4 * n**2 * en)
                 )
             )
             As = (
@@ -180,10 +175,8 @@ class SVFDModeSolver(ModeSolver):
                 * (q * (ep - en) + 2 * n * en)
                 * es
                 / (
-                    (q * (ep - en) + 2 * n * en)
-                    * (q**2 * (ep - es) + 4 * s**2 * es)
-                    + (q * (ep - es) + 2 * s * es)
-                    * (q**2 * (ep - en) + 4 * n**2 * en)
+                    (q * (ep - en) + 2 * n * en) * (q**2 * (ep - es) + 4 * s**2 * es)
+                    + (q * (ep - es) + 2 * s * es) * (q**2 * (ep - en) + 4 * n**2 * en)
                 )
             )
             Ae = 2 / e / (e + w)
@@ -255,14 +248,14 @@ class SVFDModeSolver(ModeSolver):
         return A
 
     def solve(self, neigs, tol):
-        from scipy.sparse.linalg import eigen
+        from scipy.sparse import linalg
 
         self.nmodes = neigs
         self.tol = tol
 
         A = self.build_matrix()
 
-        eigvals, eigvecs = eigen.eigs(  # type: ignore
+        eigvals, eigvecs = linalg.eigs(  # type: ignore
             A, k=neigs, which="LR", tol=tol, ncv=10 * neigs, return_eigenvectors=True
         )
 
@@ -296,7 +289,6 @@ class SVFDModeSolver(ModeSolver):
 
 
 class VFDModeSolver(ModeSolver):
-
     """
     The VFDModeSolver class computes the electric and magnetic fields
     for modes of a dielectric waveguide using the "Vector Finite
@@ -1135,12 +1127,7 @@ class VFDModeSolver(ModeSolver):
                 (n * ezz1 * ezz2 / eyy1 + s * ezz2 * ezz1 / eyy2)
                 * (
                     0.5 * n * ezz4 * ezz3 / eyy4 * (2.0 / e**2 - eyx4 / ezz4 / n / e)
-                    + 0.5
-                    * s
-                    * ezz3
-                    * ezz4
-                    / eyy3
-                    * (2.0 / e**2 + eyx3 / ezz3 / s / e)
+                    + 0.5 * s * ezz3 * ezz4 / eyy3 * (2.0 / e**2 + eyx3 / ezz3 / s / e)
                 )
                 / ezz4
                 / ezz3
@@ -1190,12 +1177,7 @@ class VFDModeSolver(ModeSolver):
                 (-n * ezz4 * ezz3 / eyy4 - s * ezz3 * ezz4 / eyy3)
                 * (
                     0.5 * n * ezz1 * ezz2 / eyy1 * (2.0 / w**2 + eyx1 / ezz1 / n / w)
-                    + 0.5
-                    * s
-                    * ezz2
-                    * ezz1
-                    / eyy2
-                    * (2.0 / w**2 - eyx2 / ezz2 / s / w)
+                    + 0.5 * s * ezz2 * ezz1 / eyy2 * (2.0 / w**2 - eyx2 / ezz2 / s / w)
                 )
                 / ezz4
                 / ezz3
@@ -1517,12 +1499,7 @@ class VFDModeSolver(ModeSolver):
                 + (ezz3 / exx2 * ezz2 * w + ezz2 / exx3 * ezz3 * e)
                 * (
                     0.5 * ezz4 * (2.0 / n**2 + exy1 / ezz1 / n / w) / exx1 * ezz1 * w
-                    + 0.5
-                    * ezz1
-                    * (2.0 / n**2 - exy4 / ezz4 / n / e)
-                    / exx4
-                    * ezz4
-                    * e
+                    + 0.5 * ezz1 * (2.0 / n**2 - exy4 / ezz4 / n / e) / exx4 * ezz4 * e
                 )
                 / ezz3
                 / ezz2
@@ -1572,12 +1549,7 @@ class VFDModeSolver(ModeSolver):
                 - (ezz4 / exx1 * ezz1 * w + ezz1 / exx4 * ezz4 * e)
                 * (
                     0.5 * ezz3 * (2.0 / s**2 - exy2 / ezz2 / s / w) / exx2 * ezz2 * w
-                    + 0.5
-                    * ezz2
-                    * (2.0 / s**2 + exy3 / ezz3 / s / e)
-                    / exx3
-                    * ezz3
-                    * e
+                    + 0.5 * ezz2 * (2.0 / s**2 + exy3 / ezz3 / s / e) / exx3 * ezz3 * e
                 )
                 / ezz3
                 / ezz2
@@ -2066,7 +2038,7 @@ class VFDModeSolver(ModeSolver):
             Ez = solver.modes[0].Ez
         """
 
-        from scipy.sparse.linalg import eigen
+        from scipy.sparse import linalg
 
         self.nmodes = neigs
         self.tol = tol
@@ -2081,7 +2053,7 @@ class VFDModeSolver(ModeSolver):
             shift = None
 
         # Here is where the actual mode-solving takes place!
-        [eigvals, eigvecs] = eigen.eigs(
+        [eigvals, eigvecs] = linalg.eigs(
             A,
             k=neigs,
             which="LR",
@@ -2320,14 +2292,9 @@ class FDMode(Mode):
 
     @staticmethod
     def plot_field(x, y, field):
-        try:
-            import pylab
-        except ImportError:
-            print("no pylab installed")
-            return
-        pylab.hot()
-        pylab.contour(x, y, numpy.abs(field.T), 16)
-        pylab.axis("image")
+        plt.hot()
+        plt.contour(x, y, numpy.abs(field.T), 16)
+        plt.axis("image")
 
     def plot_Ex(self, x=None, y=None):
         if x is None:
@@ -2385,30 +2352,25 @@ class FDMode(Mode):
 
     def plot(self):
         """Plot the mode's fields."""
-        try:
-            import pylab
-        except ImportError:
-            print("no pylab installed")
-            return
-        pylab.figure()
-        pylab.subplot(2, 3, 1)
+        plt.figure()
+        plt.subplot(2, 3, 1)
         self.plot_Ex()
-        pylab.title("Ex")
-        pylab.subplot(2, 3, 2)
+        plt.title("Ex")
+        plt.subplot(2, 3, 2)
         self.plot_Ey()
-        pylab.title("Ey")
-        pylab.subplot(2, 3, 3)
+        plt.title("Ey")
+        plt.subplot(2, 3, 3)
         self.plot_Ez()
-        pylab.title("Ez")
-        pylab.subplot(2, 3, 4)
+        plt.title("Ez")
+        plt.subplot(2, 3, 4)
         self.plot_Hx()
-        pylab.title("Hx")
-        pylab.subplot(2, 3, 5)
+        plt.title("Hx")
+        plt.subplot(2, 3, 5)
         self.plot_Hy()
-        pylab.title("Hy")
-        pylab.subplot(2, 3, 6)
+        plt.title("Hy")
+        plt.subplot(2, 3, 6)
         self.plot_Hz()
-        pylab.title("Hz")
+        plt.title("Hz")
 
 
 def stretchmesh(x, y, nlayers, factor, method="PPPP"):
